@@ -1,24 +1,29 @@
 /*
- * Asterisk
- * 
- * Mark Spencer <markster@marko.net>
+ * Asterisk -- An open source telephony toolkit.
  *
- * Copyright(C) Mark Spencer
- * 
- * Distributed under the terms of the GNU General Public License (GPL) Version 2
+ * Copyright (C) 1999 - 2005, Digium, Inc.
  *
- * I/O Managment (derived from Cheops-NG)
+ * Mark Spencer <markster@digium.com>
  *
+ * See http://www.asterisk.org for more information about
+ * the Asterisk project. Please do not directly contact
+ * any of the maintainers of this project for assistance;
+ * the project provides a web site, mailing lists and IRC
+ * channels for your use.
+ *
+ * This program is free software, distributed under the terms of
+ * the GNU General Public License Version 2. See the LICENSE file
+ * at the top of the source tree.
  */
 
-#ifndef _IO_H
-#define _IO_H
+/*! \file
+ * \brief I/O Management (derived from Cheops-NG)
+ */
 
-#ifdef POLLCOMPAT
-#include <asterisk/poll-compat.h>
-#else
-#include <sys/poll.h>		/* For POLL* constants */
-#endif
+#ifndef _ASTERISK_IO_H
+#define _ASTERISK_IO_H
+
+#include "asterisk/poll-compat.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -47,38 +52,38 @@ extern "C" {
 
 struct io_context;
 
-//! Creates a context
+/*! Creates a context */
 /*!
  * Create a context for I/O operations
  * Basically mallocs an IO structure and sets up some default values.
  * Returns an allocated io_context structure
  */
-extern struct io_context *io_context_create(void);
+struct io_context *io_context_create(void);
 
-//! Destroys a context
+/*! Destroys a context */
 /*
  * \param ioc structure to destroy
  * Destroy a context for I/O operations
  * Frees all memory associated with the given io_context structure along with the structure itself
  */
-extern void io_context_destroy(struct io_context *ioc);
+void io_context_destroy(struct io_context *ioc);
 
 typedef int (*ast_io_cb)(int *id, int fd, short events, void *cbdata);
 #define AST_IO_CB(a) ((ast_io_cb)(a))
 
-//! Adds an IO context
-/*! 
+/*! Adds an IO context */
+/*!
  * \param ioc which context to use
  * \param fd which fd to monitor
  * \param callback callback function to run
  * \param events event mask of events to wait for
  * \param data data to pass to the callback
- * Watch for any of revents activites on fd, calling callback with data as 
+ * Watch for any of revents activites on fd, calling callback with data as
  * callback data.  Returns a pointer to ID of the IO event, or NULL on failure.
  */
-extern int *ast_io_add(struct io_context *ioc, int fd, ast_io_cb callback, short events, void *data);
+int *ast_io_add(struct io_context *ioc, int fd, ast_io_cb callback, short events, void *data);
 
-//! Changes an IO handler
+/*! Changes an IO handler */
 /*!
  * \param ioc which context to use
  * \param id
@@ -90,17 +95,17 @@ extern int *ast_io_add(struct io_context *ioc, int fd, ast_io_cb callback, short
  * if >-1, and data if non-null.  Returns a pointero to the ID of the IO event,
  * or NULL on failure.
  */
-extern int *ast_io_change(struct io_context *ioc, int *id, int fd, ast_io_cb callback, short events, void *data);
+int *ast_io_change(struct io_context *ioc, int *id, int fd, ast_io_cb callback, short events, void *data);
 
-//! Removes an IO context
-/*! 
+/*! Removes an IO context */
+/*!
  * \param ioc which io_context to remove it from
  * \param id which ID to remove
  * Remove an I/O id from consideration  Returns 0 on success or -1 on failure.
  */
-extern int ast_io_remove(struct io_context *ioc, int *id);
+int ast_io_remove(struct io_context *ioc, int *id);
 
-//! Waits for IO
+/*! Waits for IO */
 /*!
  * \param ioc which context to act upon
  * \param howlong how many milliseconds to wait
@@ -109,29 +114,28 @@ extern int ast_io_remove(struct io_context *ioc, int *id);
  * any necessary I/O.  Returns the number of
  * I/O events which took place.
  */
-extern int ast_io_wait(struct io_context *ioc, int howlong);
+int ast_io_wait(struct io_context *ioc, int howlong);
 
-//! Dumps the IO array
+/*! Dumps the IO array */
 /*
  * Debugging: Dump everything in the I/O array
  */
-extern void ast_io_dump(struct io_context *ioc);
+void ast_io_dump(struct io_context *ioc);
 
-//! Set fd into non-echoing mode (if fd is a tty)
+/*! Set fd into non-echoing mode (if fd is a tty) */
 
-extern int ast_hide_password(int fd);
+int ast_hide_password(int fd);
 
-//! Restores TTY mode
+/*! Restores TTY mode */
 /*
  * Call with result from previous ast_hide_password
  */
-extern int ast_restore_tty(int fd, int oldstatus);
+int ast_restore_tty(int fd, int oldstatus);
 
-extern int ast_get_termcols(int fd);
+int ast_get_termcols(int fd);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
 
-
-#endif
+#endif /* _ASTERISK_IO_H */
